==> freerdp-2.3.0-4-x86_64.pkg.tar.lz: usr/lib/cmake/FreeRDP-Shadow2/FreeRDP-ShadowTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "freerdp-shadow" for configuration "None"
set_property(TARGET freerdp-shadow APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(freerdp-shadow PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "freerdp;freerdp-server;winpr;winpr-tools"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libfreerdp-shadow2.so.2.3.0"
  IMPORTED_SONAME_NONE "libfreerdp-shadow2.so.2"
  )

list(APPEND _cmake_import_check_targets freerdp-shadow )
list(APPEND _cmake_import_check_files_for_freerdp-shadow "${_IMPORT_PREFIX}/lib/libfreerdp-shadow2.so.2.3.0" )

# Import target "freerdp-shadow-subsystem" for configuration "None"
set_property(TARGET freerdp-shadow-subsystem APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(freerdp-shadow-subsystem PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "freerdp-shadow;freerdp;winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libfreerdp-shadow-subsystem2.so.2.3.0"
  IMPORTED_SONAME_NONE "libfreerdp-shadow-subsystem2.so.2"
  )

list(APPEND _cmake_import_check_targets freerdp-shadow-subsystem )
list(APPEND _cmake_import_check_files_for_freerdp-shadow-subsystem "${_IMPORT_PREFIX}/lib/libfreerdp-shadow-subsystem2.so.2.3.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> freerdp-2.6.1-1-x86_64.pkg.tar.lz: usr/lib/cmake/FreeRDP-Shadow2/FreeRDP-ShadowTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "freerdp-shadow" for configuration "None"
set_property(TARGET freerdp-shadow APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(freerdp-shadow PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "freerdp;freerdp-server;winpr;winpr-tools"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libfreerdp-shadow2.so.2.6.1"
  IMPORTED_SONAME_NONE "libfreerdp-shadow2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS freerdp-shadow )
list(APPEND _IMPORT_CHECK_FILES_FOR_freerdp-shadow "${_IMPORT_PREFIX}/lib/libfreerdp-shadow2.so.2.6.1" )

# Import target "freerdp-shadow-subsystem" for configuration "None"
set_property(TARGET freerdp-shadow-subsystem APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(freerdp-shadow-subsystem PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "freerdp-shadow;freerdp;winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libfreerdp-shadow-subsystem2.so.2.6.1"
  IMPORTED_SONAME_NONE "libfreerdp-shadow-subsystem2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS freerdp-shadow-subsystem )
list(APPEND _IMPORT_CHECK_FILES_FOR_freerdp-shadow-subsystem "${_IMPORT_PREFIX}/lib/libfreerdp-shadow-subsystem2.so.2.6.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
